@@ -2,7 +2,6 @@ from dez.http.application import HTTPApplication
 
 def main(**kwargs):
     a = HTTPApplication("", kwargs['port'])
-    a.add_proxy_rule('/', 'www.brbx.com', 80)
+    a.add_proxy_rule('/', kwargs['domain'], 80)
     a.add_static_rule('/static/', '.')
-    a.start()    
-
+    a.start()
\ No newline at end of file
