@@ -41,8 +41,8 @@ def response_body_cb(response, size, request):
     request.write(response.body.get_value())
     response.body.reset()
         
-def main(port):
+def main(**kwargs):
     event.signal(2, event.abort)
-    server = HTTPDaemon("", port)
+    server = HTTPDaemon("", kwargs['port'])
     server.register_prefix("/", proxy)
     event.dispatch()
